# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Data-Alias
Version:	1.28
Release:	2.%{__distinit}%{__distvers}
Summary:	Comprehensive set of aliasing operations
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Data-Alias
Source0:	https://cpan.metacpan.org/modules/by-module/Data/Data-Alias-%{version}.tar.gz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(Config)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(DynaLoader)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Carp)
BuildRequires:	perl(lib)
BuildRequires:	perl(vars)
# Optional Tests
%if 0%{?fedora:1}
BuildRequires:	perl(Devel::CallParser)
%endif
BuildRequires:	perl(Filter::Util::Call)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage)
BuildRequires:	perl(threads)
BuildRequires:	perl(threads::shared)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif

# Don't "provide" private Perl libs
%{?perl_default_filter}

%description
Aliasing is the phenomenon where two different expressions actually refer
to the same thing. Modifying one will modify the other, and if you take a
reference to both, the two values are the same.

%prep
%setup -q -n Data-Alias-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc README Changes
%{perl_vendorarch}/auto/Data/
%{perl_vendorarch}/Data/
%{_mandir}/man3/Data::Alias.3*

%changelog
* Fri Jul 14 2023 Paul Howarth <paul@city-fan.org> - 1.28-2
- Perl 5.38 rebuild

* Thu Dec 22 2022 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Fix compatibility with perl 5.37.3 and later
  - Fix support for state-variables (alias state $x = ...)
  - Fix handling of negative literal array index (alias $x[-1] = ...)

* Fri Dec  2 2022 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Fix localized alias-assignment to previously non-existing hash element
  - Avoid testing threading on broken perl versions
  - Fix certain linker errors by making sure perl's global variables are
    accessed through their accessor functions when applicable
  - Fix compile error when using perl 5.37.2 or later
  - Improve diagnostic output from tests
- Use SPDX-format license tag

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1.25-2
- Perl 5.34 rebuild

* Wed May 12 2021 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Reformatted Changes file per CPAN::Changes::Spec
  - Switched from Module::Install to ExtUtils::MakeMaker
  - Fix linker errors with dtrace-enabled perl

* Wed May  5 2021 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Bug fix: copy() no longer produces malformed optrees, which under certain
    circumstances crashed perl 5.31.2 and later
  - Update for removal of '.' from @INC in perl 5.26

* Tue May  4 2021 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Fix aliasing semantic unintentionally being applied to subs defined after a
    parenthesized alias()-expression since perl 5.11.2

* Fri Apr 23 2021 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Use SvCUR_set instead of direct SvCUR assignment to fix compilation
    problems with -DDEBUGGING builds
  - Update for parser changes in v5.33.5-62-gc588171e62
- Switch upstream from search.cpan.org to metacpan.org

* Fri Dec  8 2017 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - Update for context stack changes in Perl 5.23.8
  - Update to accommodate PERL_OP_PARENT builds of Perl 5.21.11 or later
    (which is the default from Perl 5.25.1)
  - Update for removal of LEX_KNOWNEXT in Perl 5.25.1
  - Update test suite to not rely on . in @INC, which is no longer
    necessarily there from Perl 5.25.7
  - Use cleaner wrap_op_checker() API to control op checking
- BR: perl-devel and perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section

* Fri Aug 12 2016 Paul Howarth <paul@city-fan.org> - 1.20-3
- BR: perl-generators where available
- Simplify find commands using -empty and -delete

* Thu Oct 22 2015 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - Avoid some C undefined behaviour from unsequenced side effects that in
    practice bit when using a newer gcc (4.9 rather than 4.7) with the parser
    token stack change in Perl 5.21.9
  - Add doc note advising users to prefer the core aliasing facility on
    Perl 5.22

* Wed Oct 21 2015 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - Update for new stricture on op_last in Perl 5.21.2
  - Update for the parser's PL_expect changes in Perl 5.21.4
  - Update for op_private stricture in Perl 5.21.4
  - Update for sub references directly in stash in Perl 5.21.4
  - Update for IS_PADGV()'s limited visibility in Perl 5.21.4
  - Update for increased specialness of OP_PUSHMARK in Perl 5.21.6
  - Update for distinct PADNAMELIST type in Perl 5.21.7
  - Update for multideref optimisation in Perl 5.21.7, by a disgusting hack
    that depends on a flaw in the optimisation (which may disappear in the
    future) and which disables the optimisation entirely
  - Add MYMETA.json to .gitignore
- Classify buildreqs by usage
- Explicitly BR: perl-devel, needed for EXTERN.h

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 1.18-4
- Drop %%defattr, redundant since rpm 4.4

* Sat Sep 21 2013 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18:
  - Bugfix: store peep chain link reliably under threads
  - Update tests for Perl 5.19.4's removal of the special treatment of aliased
    undef in arrays
  - In documentation, switch to consistent use of British English spellings
  - Documentation typo fix

* Sun Aug  4 2013 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17:
  - Bugfix: correct the dtrace-related macro squashing for Perls prior
    to 5.13.8, where the macros had the wrong number of parameters and
    prevented compilation
  - Bugfix: use core's PL_no_localize_ref string constant as data string
    rather than format string
  - Update to handle the new padrange op type in Perl 5.17.6
  - Update to handle the new op allocation mechanism in Perl 5.17.2
  - Clarify and expand documentation around list-like assignments
  - Clarify documentation of deref() regarding lvalueness
  - Remove the bulk of the documentation from the README file

* Wed Jun 27 2012 Paul Howarth <paul@city-fan.org> - 1.16-2
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Mon Feb 20 2012 Paul Howarth <paul@city-fan.org> - 1.16-1
- Import from Fedora
- Update to 1.16:
  - Use supported API to put destructor calls on the save stack (the
    unsupported way used before was wrong for 64-bit systems on perl 5.13.1
    and later)
  - Document the behaviour of "alias return" in more detail
  - Convert .cvsignore to .gitignore
- Add patch to fix build with Perl 5.12.x (CPAN RT#75156)

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.15-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Fri Jun 24 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.15-3
- Perl mass rebuild

* Fri Jun 24 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.15-2
- Perl mass rebuild

* Fri Jun 24 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.15-1
- Update to 1.15, which fixes issues with systemtap

* Mon Jun 20 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.12-2
- Perl mass rebuild

* Thu Apr 14 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.12-1
- Specfile autogenerated by cpanspec 1.79 for new release; this package was
  resurrected for 5.12.x

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 1.07-6
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.07-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.07-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Thu Mar 06 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.07-3
- Rebuild for new perl

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.07-2
- Autorebuild for GCC 4.3

* Mon Nov 05 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.07-1
- Update to 1.07

* Tue Aug 21 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.06-2
- Bump

* Fri Aug 10 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.06-1
- Update to 1.06
- License tag: GPL -> GPL+

* Fri Jun 01 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.05-1
- Update to 1.05

* Fri May 04 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.04-1
- Update to 1.04
- Add t/ to %%doc
- Perl splittage BR's added

* Mon Mar 19 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.03-1
- Update to 1.03

* Mon Feb 19 2007 Chris Weyl <cweyl@alumni.drew.edu> - 1.02-1
- Update to 1.02

* Tue Oct 03 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.01-1
- Update to 1.01

* Thu Aug 31 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.0-3
- Bump for mass rebuild

* Thu Aug 17 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.0-2
- Bump for build & release

* Wed Aug 16 2006 Chris Weyl <cweyl@alumni.drew.edu> - 1.0-1
- Specfile autogenerated by cpanspec 1.68
- Initial spec file for F-E
